from distutils.core import setup

setup(
    name='spookyaction',
    version='0.0.4',
    author='Adam Short',
    author_email='adam010101@icloud.com',
    packages=['spookyaction'],
    url='http://pypi.python.org/pypi/TowelStuff/',
    license='LICENSE.txt',
    description='A framework for pyautogui automation.',
    long_description=open('README.txt').read(),
)
